@@ -5,7 +5,9 @@ BEGIN {
 		use vars 	qw($VERSION @ISA @EXPORT @EXPORT_OK); # %EXPORT_TAGS);
 		use strict;
 
-		$VERSION	= 0.8035; # a.ammr a.a anne d'existence, mm mois, r release
+		# a.ammr a.a anne d'existence, mm mois, r release
+		$VERSION	= 0.8051; 
+		$YEAR	= '2013';
 		@ISA		= qw(Exporter);
 		@EXPORT	= qw(oEdtk_release);
 }
@@ -16,7 +18,7 @@ BEGIN {
 
 sub oEdtk_release {
 	# warn "DEBUG: >$?< \nDEBUG: >$@<\n";
-	return "\n(c) 2005-2013 daunay\@cpan.org - edtk\@free.fr - oEdtk v$VERSION\n";
+	return "\n(c) 2005-$YEAR daunay\@cpan.org - edtk\@free.fr - oEdtk v$VERSION\n";
 }
 
 
@@ -351,14 +353,14 @@ Example :
 
 =head1 AUTHORS
 
-oEdtk by D Aunay, GJ Chaillou Domingo, M Henrion 2005-2011.
+oEdtk by D Aunay, GJ Chaillou Domingo, M Henrion, G Ballin 2005-$YEAR.
 
 This pod text by GJ Chaillou Domingo, M Henrion and others.
 Perl by Larry Wall and the C<perl5-porters>.
 
 =head1 COPYRIGHT
 
-The oEdtk module is Copyright (c) 2005-2011 D Aunay, GJ Chaillou Domingo, M Henrion.
+The oEdtk module is Copyright (c) 2005-$YEAR D Aunay, GJ Chaillou Domingo, M Henrion, G Ballin.
 All rights reserved.
 
 You may distribute under the terms of either the GNU General Public
